@@ -1,5 +1,5 @@
 package Mail::DMARC::Report::Store;
-our $VERSION = '1.20130612'; # VERSION
+our $VERSION = '1.20130614'; # VERSION
 use strict;
 use warnings;
 
@@ -12,6 +12,11 @@ sub delete_report {
     return $self->backend->delete_report(@_);
 }
 
+sub error {
+    my $self = shift;
+    return $self->backend->insert_error(@_);
+}
+
 sub retrieve {
     my $self = shift;
     return $self->backend->retrieve(@_);
@@ -52,7 +57,7 @@ Mail::DMARC::Report::Store - persistent storage broker for DMARC reports
 
 =head1 VERSION
 
-version 1.20130612
+version 1.20130614
 
 =head1 SYNOPSIS
 
@@ -78,10 +83,20 @@ Davide Migliavacca <shari@cpan.org>
 
 =back
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Benny Pedersen <me@junc.eu>
+
+=item *
 
 ColocateUSA.net <company@colocateusa.net>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by ColocateUSA.com.
